@@ -302,11 +302,13 @@ class FormSet(object):
     _errors = None
     has_changed = False
 
-    def __init__(self, form_class, parent=None, create_new=True,
+    def __init__(self, form_class, parent=None,
+            create_new=True, delete_old=True,
             data=None, objs=None, files=None):
         self._form_class = form_class
         self._parent = parent
         self._create_new = bool(create_new)
+        self._delete_old = bool(delete_old)
         self._forms = []
         self._errors = {}
         self.has_changed = False
@@ -390,10 +392,18 @@ class FormSet(object):
                 self.has_changed = True
         if errors:
             self._errors = errors
-            return False
         return True
 
     def save(self, parent_obj):
         for form in self._forms:
-            form.save(parent_obj)
+            is_old = (form._model and form._obj and
+                hasattr(form._obj, 'id') and
+                hasattr(form, 'id') and form.id.empty
+            )
+            if self._delete_old and is_old:
+                db = form._model.db
+                db.query(form._model).filter(form._model.id == form._obj.id) \
+                    .delete(synchronize_session='fetch')
+            else:
+                form.save(parent_obj)
 
