@@ -103,7 +103,9 @@ def test_changed_data():
     form.message.value = data['message']
     assert form.is_valid()
     assert form.changed_fields == ['message', 'subject']
-    assert form.cleaned_data == data
+    assert form.cleaned_data['subject'] == data['subject']
+    assert form.cleaned_data['message'] == data['message']
+    assert form.cleaned_data['email'] == None
 
 
 def test_save():
@@ -425,3 +427,59 @@ def test_formset_model():
     assert addr.email == data['formaddress.1-email']
     assert addr.user == user
 
+
+def test_formset_autodelete():
+    db = SQLAlchemy()
+
+    class User(db.Model):
+        __tablename__ = 'users'
+        id = db.Column(db.Integer, primary_key=True)
+        name = db.Column(db.String)
+
+    class Address(db.Model):
+        __tablename__ = 'addresses'
+        id = db.Column(db.Integer, primary_key=True)
+        email = db.Column(db.String)
+        user_id = db.Column(db.Integer, db.ForeignKey('users.id'))
+        user = db.relationship('User',
+            backref=db.backref('addresses', lazy='dynamic'))
+
+    db.create_all()
+
+    class FormAddress(f.Form):
+        _model = Address
+        id = f.Integer()
+        email = f.Email()
+
+    class FormUser(f.Form):
+        _model = User
+        id = f.Integer()
+        name = f.Text()
+        addresses = f.FormSet(FormAddress, parent='user')
+
+    user = User(name=u'John Doe')
+    db.add(user)
+    db.add(Address(email=u'one@example.com', user=user))
+    db.add(Address(email=u'two@example.com', user=user))
+    db.add(Address(email=u'three@example.com', user=user))
+    db.commit()
+
+    data = {
+        'name': u'Jane Doe',
+        'formaddress.1-id': u'1',
+        'formaddress.1-email': u'one@example.org',
+        'formaddress.3-id': u'3',
+        'formaddress.3-email': u'three@example.org',
+        'formaddress.4-email': u'four@example.org',
+    }
+    form = FormUser(data, user)
+    assert form.is_valid()
+    form.save()
+    db.commit()
+
+    assert db.query(Address).count() == 3
+    addrs = db.query(Address).all()
+    assert addrs[0].email == data['formaddress.1-email']
+    assert addrs[1].email == data['formaddress.3-email']
+    assert addrs[2].email == data['formaddress.4-email']
+
